@@ -12,7 +12,7 @@ bt.g<-function(x){
 }
 
 n<-10
-xx <- rep(0,n)
+xx <- rep(0,n) # the start which is out of bounds
 lower <- rep(1,n)
 upper <- rep(3,n)
 bdmsk <- rep(1,n) # all free parameters
@@ -22,3 +22,11 @@ if (class(ansbt) == "try-error") {
    cat("Successful stop when out of bounds\n")
 } else { print(ansbt) }
 
+
+xx2 <- rep(2,n) # the start which is out of bounds
+ansbt2 <- try( Rvmmin(xx2, bt.f, bt.g, lower, upper, bdmsk, 
+         control=list(trace=1, keepinputpar = TRUE)) )
+if (class(ansbt2) == "try-error") {
+   cat("Successful stop when out of bounds\n")
+} else { print(ansbt2) }
+
